diff -pruN 2.1.1/debian/changelog 2.1.2/debian/changelog
--- 2.1.1/debian/changelog	2023-09-04 11:30:35.000000000 +0000
+++ 2.1.2/debian/changelog	2024-07-12 06:03:04.000000000 +0000
@@ -1,3 +1,26 @@
+dh-elpa (2.1.2) experimental; urgency=medium
+
+  [ Xiyue Deng ]
+  * Set ert-batch-backtrace-right-margin to nil to allow full backtrace
+    when ERT tests fail (Closes: #973393).
+  * Add support for passing ERT selectors using ert_selectors.
+  * Handle git version with date in dhelpa-sanitise-version.
+  * dh_elpa_test: Don't rename files under test/, tests/
+    (Closes: #1069326).
+  * Use `pretty' stack frame style in buttercup for full back trace.
+  * Add support for installing nested directories (Closes: #1069210)
+    - Don't recursively add to elpa path, to match package.el
+    - Byte-compile recursively during install
+    - Recursively create the symlinks from elpa-src->elpa.
+
+  [ Aymeric Agon-Rambosson ]
+  * Get Package-Requires with lm-header-multiline (some upstream
+    maintainers specify one dependency per line).
+  * Add transient to the list of packages packaged separately as well as
+    provided with Emacs.
+
+ -- Sean Whitton <spwhitton@spwhitton.name>  Fri, 12 Jul 2024 14:03:04 +0800
+
 dh-elpa (2.1.1) experimental; urgency=medium
 
   * Remove /usr/share/$flavor/site-lisp/elpa (from emacsen-remove)
diff -pruN 2.1.1/debian/install 2.1.2/debian/install
--- 2.1.1/debian/install	2023-09-04 11:30:35.000000000 +0000
+++ 2.1.2/debian/install	2024-07-12 06:03:04.000000000 +0000
@@ -2,3 +2,5 @@ elpa.pm usr/share/perl5/Debian/Debhelper
 emacsen-common usr/share/debhelper/dh_elpa
 autoscripts/prerm-elpa usr/share/debhelper/autoscripts
 usr/bin
+elpa/.nosearch usr/share/emacs/site-lisp/elpa
+elpa-src/.nosearch usr/share/emacs/site-lisp/elpa-src
diff -pruN 2.1.1/dh-elpa.el 2.1.2/dh-elpa.el
--- 2.1.1/dh-elpa.el	2023-09-04 11:30:35.000000000 +0000
+++ 2.1.2/dh-elpa.el	2024-07-12 06:03:04.000000000 +0000
@@ -83,7 +83,9 @@ set and disagree."
     (narrow-to-region start (point))
     (require 'lisp-mnt)
     ;; Use some headers we've invented to drive the process.
-    (let* ((requires-str (lm-header "package-requires"))
+    (let* ((requires-list (lm-header-multiline "package-requires"))
+	   (requires-str (and requires-list
+			      (mapconcat #'identity requires-list " ")))
 	   ;; Prefer Package-Version; if defined, the package author
 	   ;; probably wants us to use it.  Otherwise try Version.
 	   (pkg-version
@@ -157,9 +159,10 @@ a pre-release).  The Debian package main
 upstream source to include a proper Package-Version: header in
 such a case."
   (when version
-    (replace-regexp-in-string
-     "~" "-"
-     (replace-regexp-in-string "~bpo.*$" "" version))))
+    (let* ((version (replace-regexp-in-string "~bpo.*$" "" version))
+           (version (replace-regexp-in-string "[+-~]git.*$" "-git" version))
+           (version (replace-regexp-in-string "~" "-" version)))
+      version)))
 
 (defun null-empty-string (str)
   "If STR is a string of length zero, return nil.  Otherwise, return STR."
@@ -184,7 +187,7 @@ These are packaged separately for two re
 - it permits use of addons with older versions of Emacs, for
   which the dependency is not yet a built-in package."
   (let ((non-elpa '(emacs))
-        (packaged-separately '(let-alist seq xref org project)))
+        (packaged-separately '(let-alist transient seq xref org project)))
     (cl-remove-if (lambda (dep)
 		    (let ((pkg (car dep)))
                       (or (memq pkg non-elpa)
diff -pruN 2.1.1/dh_elpa_test 2.1.2/dh_elpa_test
--- 2.1.1/dh_elpa_test	2023-09-04 11:30:35.000000000 +0000
+++ 2.1.2/dh_elpa_test	2024-07-12 06:03:04.000000000 +0000
@@ -122,6 +122,12 @@ instance spawned by B<dh_elpa_test> to r
 A comma-separated list of directories to add to the load-path when
 B<dh_elpa_test> invokes Emacs to run ERT tests.
 
+=item B<ert_selectors>
+
+A Lisp expression specifying a set of tests.  This is the same as ERT test
+selectors and will be passed to ERT through command line, which will also work
+with custom test tools built upon ERT.
+
 =item B<autopkgtest_keep>
 
 A comma-separated list of file globs matching files that should not be
@@ -262,10 +268,16 @@ if ($autopkgtest) {
         exit 0;
     }
 
+    # Compile a list of files to be renamed during autopkgtest.  This usually
+    # renames source *.el file outside the test directories so that during
+    # autopkgtest we are testing the installed package instead of relying on
+    # source files from the source directory.
     my $rule = File::Find::Rule->new;
     $rule
       ->or(File::Find::Rule
-           ->name('.pc', 'debian', '.git')
+           ->name('.pc', 'debian', '.git', # exclude non-source directories
+                  'test', 'tests', # exclude test directories
+           )
            ->directory->prune->discard,
            File::Find::Rule->new);
     $rule
@@ -331,6 +343,8 @@ if ($autopkgtest) {
 
 if ($control->source->Build_Depends->has( "elpa-buttercup" )) {
     my @args = qw{ buttercup -L . };
+    push @args, ('--traceback', 'pretty');
+
     if (defined $options->{_}->{'buttercup_load_path'}) {
         foreach my $dir (split(',', $options->{_}->{'buttercup_load_path'})) {
             push @args, ('-L', "$dir");
@@ -367,6 +381,7 @@ if (@ert_files) {
     my @args = qw{ emacs -batch -Q -l package };
     push @args, ("--eval", "(add-to-list 'package-directory-list \"$dhelpadir\")");
     push @args, ("--eval", "(add-to-list 'package-directory-list \"$elpadir\")");
+    push @args, ("--eval", "(setq ert-batch-backtrace-right-margin nil)");
     push @args, ("-f", "package-initialize");
 
     # add the user's load-path entries
@@ -395,6 +410,10 @@ if (@ert_files) {
         push @args, ("--eval", "(ert-run-tests-batch-and-exit)");
     }
 
+    if (defined $options->{_}->{'ert_selectors'}) {
+        push @args, $options->{_}->{'ert_selectors'};
+    }
+
     print_and_doit(@args);
 }
 
diff -pruN 2.1.1/helper/install 2.1.2/helper/install
--- 2.1.1/helper/install	2023-09-04 11:30:35.000000000 +0000
+++ 2.1.2/helper/install	2024-07-12 06:03:04.000000000 +0000
@@ -50,7 +50,7 @@ echo "install/${ELPA_DIR}: byte-compilin
 # policy).  This makes complation easy, and also allows find-function
 # and find-library to work properly.  Also link all other top level
 # files and directories into the flavor directory
-(cd "${elc_dir}" && ln -sf "${el_dir}"* .)
+(cd "${elc_dir}" && cp -rsf "${el_dir}"* .)
 
 # Byte compile them
 (cd "${elc_dir}"
@@ -58,7 +58,8 @@ echo "install/${ELPA_DIR}: byte-compilin
  ${FLAVOR} --quick --batch -l package \
            --eval "(setq package-user-dir \"/nonexistent\")" \
            --eval "(add-to-list 'package-directory-list \"$src_dir\")" \
-           -f package-initialize -f batch-byte-compile ./*.el > Install.log 2>&1
+           -f package-initialize \
+           --eval "(byte-recompile-directory \".\" 0)" > Install.log 2>&1
  if test $? -ne 0
  then
    cat Install.log
